==> beast-propagation-2.7-20230115.082015-17-sources.jar: org/beast/propagation/instrument/web/WebServletPropagationAutoConfiguration.java <==
package org.beast.propagation.instrument.web;

import org.beast.propagation.Propagation;
import org.beast.propagation.PropagationAutoConfiguration;
import org.beast.propagation.context.CurrentContext;
import org.beast.propagation.instrument.web.servlet.ServletPropagationFilter;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.Ordered;

import javax.servlet.DispatcherType;

@Configuration
@ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
@AutoConfigureAfter(PropagationAutoConfiguration.class)
public class WebServletPropagationAutoConfiguration {

    @Bean
    @ConditionalOnMissingBean
    public ServletPropagationFilter servletPropagationFilter(Propagation propagation, CurrentContext currentContext) {
        return new ServletPropagationFilter(propagation, currentContext);
    }

    @Bean
    public FilterRegistrationBean shuntServletFilter(ServletPropagationFilter servletPropagationFilter) {
        FilterRegistrationBean filterRegistrationBean = new FilterRegistrationBean<>(servletPropagationFilter);
        filterRegistrationBean.setDispatcherTypes(
                DispatcherType.ASYNC,
                DispatcherType.ERROR, DispatcherType.FORWARD, DispatcherType.INCLUDE,
                DispatcherType.REQUEST
        );
        filterRegistrationBean.setOrder(
                Ordered.HIGHEST_PRECEDENCE + 5
        );
        return filterRegistrationBean;
    }

}

==> beast-propagation-3.0-20230903.093249-6-sources.jar: org/beast/propagation/instrument/web/WebServletPropagationAutoConfiguration.java <==
package org.beast.propagation.instrument.web;

import org.beast.propagation.Propagation;
import org.beast.propagation.PropagationAutoConfiguration;
import org.beast.propagation.context.CurrentContext;
import org.beast.propagation.instrument.web.servlet.ServletPropagationFilter;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.Ordered;

import jakarta.servlet.DispatcherType;

@Configuration
@ConditionalOnWebApplication(type = ConditionalOnWebApplication.Type.SERVLET)
@AutoConfigureAfter(PropagationAutoConfiguration.class)
public class WebServletPropagationAutoConfiguration {

    @Bean
    @ConditionalOnMissingBean
    public ServletPropagationFilter servletPropagationFilter(Propagation propagation, CurrentContext currentContext) {
        return new ServletPropagationFilter(propagation, currentContext);
    }

    @Bean
    public FilterRegistrationBean shuntServletFilter(ServletPropagationFilter servletPropagationFilter) {
        FilterRegistrationBean filterRegistrationBean = new FilterRegistrationBean<>(servletPropagationFilter);
        filterRegistrationBean.setDispatcherTypes(
                DispatcherType.ASYNC,
                DispatcherType.ERROR, DispatcherType.FORWARD, DispatcherType.INCLUDE,
                DispatcherType.REQUEST
        );
        filterRegistrationBean.setOrder(
                Ordered.HIGHEST_PRECEDENCE + 5
        );
        return filterRegistrationBean;
    }

}
